<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://arc-hive.zone
 * @since      1.0.0
 *
 * @package    archive_wpplugin
 * @subpackage archive_wpplugin/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the arcHIVE WP Plugin, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    archive_wpplugin
 * @subpackage archive_wpplugin/admin
 * @author     Jorge - vitrubio.net <jorge@vitrubio.net>
 */
class archive_wpplugin_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $archive_wpplugin    The ID of this plugin.
	 */
	private $archive_wpplugin;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $archive_wpplugin       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $archive_wpplugin, $version ) {

		$this->archive_wpplugin = $archive_wpplugin;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in archive_wpplugin_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The archive_wpplugin_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->archive_wpplugin, plugin_dir_url( __FILE__ ) . 'css/archive-wpplugin-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in archive_wpplugin_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The archive_wpplugin_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->archive_wpplugin, plugin_dir_url( __FILE__ ) . 'js/archive-wpplugin-admin.js', array( 'jquery' ), $this->version, false );

	}

}
